@@ -35,8 +35,11 @@ from wtforms.fields.core import UnboundField
 
 from sqladmin._types import ENGINE_TYPE, MODEL_ATTR_TYPE
 from sqladmin._validators import CurrencyValidator, TimezoneValidator
+from sqladmin.ajax import QueryAjaxModelLoader
 from sqladmin.exceptions import NoConverterFound
 from sqladmin.fields import (
+    AjaxSelectField,
+    AjaxSelectMultipleField,
     DateField,
     DateTimeField,
     JSONField,
@@ -45,7 +48,7 @@ from sqladmin.fields import (
     SelectField,
     TimeField,
 )
-from sqladmin.helpers import get_direction, get_primary_key
+from sqladmin.helpers import get_direction, get_primary_key, is_relationship
 
 if sys.version_info >= (3, 8):
     from typing import Protocol
@@ -109,6 +112,7 @@ class ModelConverterBase:
         field_widget_args: Dict[str, Any],
         form_include_pk: bool,
         label: Optional[str] = None,
+        loader: Optional[QueryAjaxModelLoader] = None,
     ) -> Optional[Dict[str, Any]]:
         kwargs: Union[dict, None]
         kwargs = field_args.copy()
@@ -128,7 +132,7 @@ class ModelConverterBase:
             )
         else:
             kwargs = await self._prepare_relationship(
-                prop=prop, engine=engine, kwargs=kwargs
+                prop=prop, engine=engine, kwargs=kwargs, loader=loader
             )
 
         return kwargs
@@ -174,7 +178,11 @@ class ModelConverterBase:
         return kwargs
 
     async def _prepare_relationship(
-        self, prop: RelationshipProperty, kwargs: dict, engine: ENGINE_TYPE
+        self,
+        prop: RelationshipProperty,
+        kwargs: dict,
+        engine: ENGINE_TYPE,
+        loader: Optional[QueryAjaxModelLoader] = None,
     ) -> dict:
         nullable = True
         for pair in prop.local_remote_pairs:
@@ -182,7 +190,9 @@ class ModelConverterBase:
                 nullable = False
 
         kwargs["allow_blank"] = nullable
-        kwargs.setdefault("data", await self._prepare_select_options(prop, engine))
+
+        if not loader:
+            kwargs.setdefault("data", await self._prepare_select_options(prop, engine))
 
         return kwargs
 
@@ -193,7 +203,7 @@ class ModelConverterBase:
     ) -> List[Tuple[str, Any]]:
         target_model = prop.mapper.class_
         pk = get_primary_key(target_model)
-        stmt = select(target_model)
+        stmt = select(target_model).limit(100)
 
         if isinstance(engine, Engine):
             with Session(engine) as session:
@@ -256,8 +266,10 @@ class ModelConverterBase:
         form_include_pk: bool,
         label: Optional[str] = None,
         override: Optional[Type[Field]] = None,
+        form_ajax_refs: Dict[str, QueryAjaxModelLoader] = {},
     ) -> Optional[UnboundField]:
 
+        loader = form_ajax_refs.get(prop.key)
         kwargs = await self._prepare_kwargs(
             prop=prop,
             engine=engine,
@@ -265,6 +277,7 @@ class ModelConverterBase:
             field_widget_args=field_widget_args,
             label=label,
             form_include_pk=form_include_pk,
+            loader=loader,
         )
 
         if kwargs is None:
@@ -274,6 +287,18 @@ class ModelConverterBase:
             assert issubclass(override, Field)
             return override(**kwargs)
 
+        multiple = (
+            is_relationship(prop)
+            and prop.direction.name in ("ONETOMANY", "MANYTOMANY")
+            and prop.uselist
+        )
+
+        if loader:
+            if multiple:
+                return AjaxSelectMultipleField(loader, **kwargs)
+            else:
+                return AjaxSelectField(loader, **kwargs)
+
         converter = self.get_converter(prop=prop)
         return converter(model=model, prop=prop, kwargs=kwargs)
 
@@ -312,8 +337,6 @@ class ModelConverter(ModelConverterBase):
     def conv_boolean(
         self, model: type, prop: ColumnProperty, kwargs: Dict[str, Any]
     ) -> UnboundField:
-        kwargs.setdefault("render_kw", {})
-        kwargs["render_kw"]["class"] = "form-check-input"
         return BooleanField(**kwargs)
 
     @converts("Date")
@@ -477,6 +500,7 @@ async def get_model_form(
     form_widget_args: Dict[str, Dict[str, Any]] = None,
     form_class: Type[Form] = Form,
     form_overrides: Dict[str, Type[Field]] = None,
+    form_ajax_refs: Dict[str, QueryAjaxModelLoader] = None,
     form_include_pk: bool = False,
 ) -> Type[Form]:
     type_name = model.__name__ + "Form"
@@ -486,6 +510,7 @@ async def get_model_form(
     form_widget_args = form_widget_args or {}
     column_labels = column_labels or {}
     form_overrides = form_overrides or {}
+    form_ajax_refs = form_ajax_refs or {}
 
     attributes = []
     names = only or mapper.attrs.keys()
@@ -509,6 +534,7 @@ async def get_model_form(
             label=label,
             override=override,
             form_include_pk=form_include_pk,
+            form_ajax_refs=form_ajax_refs,
         )
         if field is not None:
             field_dict[name] = field
