@@ -14,6 +14,7 @@ from typing import (
     Union,
     no_type_check,
 )
+from urllib.parse import urlencode
 
 import anyio
 from sqlalchemy import Column, asc, desc, func, inspect, or_
@@ -32,15 +33,9 @@ from starlette.responses import StreamingResponse
 from starlette.templating import Jinja2Templates
 from wtforms import Field, Form
 
-from sqladmin._queries import (
-    delete_async,
-    delete_sync,
-    insert_async,
-    insert_sync,
-    update_async,
-    update_sync,
-)
+from sqladmin._queries import Query
 from sqladmin._types import ENGINE_TYPE, MODEL_ATTR_TYPE
+from sqladmin.ajax import create_ajax_loader
 from sqladmin.exceptions import InvalidColumnError, InvalidModelError
 from sqladmin.formatters import BASE_FORMATTERS
 from sqladmin.forms import get_model_form
@@ -206,6 +201,7 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
     engine: ClassVar[ENGINE_TYPE]
     async_engine: ClassVar[bool]
     is_model: ClassVar[bool] = True
+    ajax_lookup_url: ClassVar[str] = ""
 
     name_plural: ClassVar[str] = ""
     """Plural name of ModelView.
@@ -554,6 +550,23 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
         ```
     """
 
+    form_ajax_refs: ClassVar[Dict[str, dict]] = {}
+    """Use Ajax for foreign key model loading.
+    Should contain dictionary, where key is field name and
+    value is a dictionary which configures Ajax lookups.
+
+    ???+example
+        ```python
+        class UserAdmin(ModelAdmin, model=User):
+            form_ajax_refs = {
+                'address': {
+                    'fields': ('street', 'zip_code'),
+                    'order_by': ('id',),
+                }
+            }
+        ```
+    """
+
     # General options
     column_labels: ClassVar[Dict[Union[str, InstrumentedAttribute], str]] = {}
     """A mapping of column labels, used to map column names to new names.
@@ -662,6 +675,12 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
             for attr in self.column_sortable_list
         ]
 
+        self._form_ajax_refs = {}
+        for name, options in self.form_ajax_refs.items():
+            self._form_ajax_refs[name] = create_ajax_loader(
+                model_admin=self, name=name, options=options
+            )
+
     def _run_query_sync(self, stmt: ClauseElement) -> Any:
         with self.sessionmaker(expire_on_commit=False) as session:
             result = session.execute(stmt)
@@ -693,11 +712,11 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
 
     def _url_for_delete(self, obj: Any) -> str:
         pk = getattr(obj, get_primary_key(obj).name)
-        return self.url_path_for(
-            "admin:delete",
-            identity=slugify_class_name(obj.__class__.__name__),
-            pk=pk,
+        query_params = urlencode({"pks": pk})
+        url = self.url_path_for(
+            "admin:delete", identity=slugify_class_name(obj.__class__.__name__)
         )
+        return url + "?" + query_params
 
     def _url_for_details_with_attr(self, obj: Any, attr: RelationshipProperty) -> str:
         target = getattr(obj, attr.key)
@@ -834,20 +853,15 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
         self, attr: Union[str, InstrumentedAttribute]
     ) -> MODEL_ATTR_TYPE:
         assert isinstance(attr, (str, InstrumentedAttribute))
+        attrs = inspect(self.model).attrs
 
         if isinstance(attr, str):
             key = attr
-        elif isinstance(attr.prop, ColumnProperty):
-            key = attr.key
-        elif isinstance(attr.prop, RelationshipProperty):
+        else:
             key = attr.prop.key
 
-        if key in inspect(self.model).attrs:
-            return inspect(self.model).attrs[key]
-
-        # Get value by column label
-        if key in self._column_labels_value_by_key:
-            return self._column_labels_value_by_key[str(key)]
+        if key in attrs:
+            return attrs[key]
 
         raise InvalidColumnError(
             f"Model '{self.model.__name__}' has no attribute '{key}'."
@@ -937,22 +951,13 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
         }
 
     async def delete_model(self, obj: Any) -> None:
-        if self.async_engine:
-            await delete_async(self, obj)
-        else:
-            await anyio.to_thread.run_sync(delete_sync, self, obj)
+        await Query(self).delete(obj)
 
     async def insert_model(self, data: dict) -> None:
-        if self.async_engine:
-            await insert_async(self, data)
-        else:
-            await anyio.to_thread.run_sync(insert_sync, self, data)
+        await Query(self).insert(data)
 
     async def update_model(self, pk: Any, data: Dict[str, Any]) -> None:
-        if self.async_engine:
-            await update_async(self, pk, data)
-        else:
-            await anyio.to_thread.run_sync(update_sync, self, pk, data)
+        await Query(self).update(pk, data)
 
     async def scaffold_form(self) -> Type[Form]:
         if self.form is not None:
@@ -966,6 +971,7 @@ class ModelView(BaseView, metaclass=ModelViewMeta):
             form_widget_args=self.form_widget_args,
             form_class=self.form_base_class,
             form_overrides=self.form_overrides,
+            form_ajax_refs=self._form_ajax_refs,
             form_include_pk=self.form_include_pk,
         )
 
